==> JVPC-0.93.zip: JVPC-0.93/blitz/Blitz.java <==
/**
 * Plug-in for Java VGA-Planets clients, that enables a permanent network
 * connection to the hosting service. The Host will send warnings when the host
 * will be ran. In particular, "host 30" will be sent, which means the host
 * will be ran in 30 seconds. The client should result make a TRN and send it
 * back over the same line.
 *
 * Two Submit buttons (in two windows) confusing?
 */

package jvpc.blitz;

import java.io.*;
import java.net.*;

import java.awt.*;
import java.awt.event.*;
import kero.awt.*;

import jvpc.vga.*;

public class Blitz extends MyFrame {
    FrameAdapter adapter;
    Label dir_name;
    Button change, join;
    InputField host, game, race;
    IntInput port;
    MySocket socket;
    String some_path;
    InputFileOpener ifo;

    public class BlitzAdapter extends FrameAdapter {
	public void quit() {
	    try {
		System.err.println("Quitting...");
		if (socket != null) {  // if never joined, no socket
		    socket.close();
		}
	    } catch (IOException ioe) {
		// What now? Is it closed?
	    }
	    System.exit(0);
	}
    }

    public Blitz(String some_path) {
	super("Blitz Info");
	this.some_path = some_path;
	// this.ifo = ifo;
	setLayout(new GridLayout(0, 1));
	adapter = new BlitzAdapter();
	addWindowListener(adapter);

	Panel dir_p = new Panel(new GridLayout(1, 0));
	dir_p.add(new Label("Directory:"));
	dir_name = new Label(some_path);
	dir_p.add(dir_name);
	change = new Button("Change...");
	addButtonTo(dir_p, change, KeyEvent.VK_C, "change_dir");
	add(dir_p);

	Panel p = new Panel(new FlowLayout());
        host = new InputField("Ip", "213.46.3.75");
	addInputFieldTo(p, host, KeyEvent.VK_I, "empty");
        port = new IntInput("Port", 9000, 1, 0);
	addNumberInputTo(p, port, KeyEvent.VK_P, "empty");
	add(p);
	game = new InputField("Game", "blitz");
	addInputField(game, KeyEvent.VK_G, "empty");
	race = new InputField("Race", "3");
	addInputField(race, KeyEvent.VK_R, "empty");
	join = new Button("Join");
	addButton(join, KeyEvent.VK_J, "join");
	pack();
	show();
    }

    public void change_dir() {
	FileDialog dialog = new FileDialog(this, "GameDir", FileDialog.SAVE);
	dialog.setFile("fizz.bin");
	dialog.setDirectory(some_path);
	dialog.show();
	some_path = dialog.getDirectory();
	// System.err.println("Got dir "+dialog.getDirectory());
	// System.err.println("Got file "+dialog.getFile());
	dir_name.setText(some_path);
	// System.err.println("Got dir "+dialog.getDirectory());
	// System.err.println("Got file "+dialog.getFile());
	pack();
	// show();
    }
    
    public void empty() {}

    public void join() {
	try {
	    socket = new MySocket(host.getText(), port.getInt());
	    socket.write("join "+game.getText()+" "+race.getText()+"\n");
	    String str = socket.gets();
	    System.err.println(str);
	    StreamTokenizer tokenizer = new StreamTokenizer(new StringReader(str));
	    tokenizer.nextToken();
	    String result = tokenizer.sval;
	    if (result.equals("OK")) {
		ifo = new InputFileOpener(some_path, ""+some_path);
		show(false);
		tokenizer.nextToken(); // Game
		tokenizer.nextToken(); // <name>
		tokenizer.nextToken(); // joined
		tokenizer.nextToken(); // as
		tokenizer.nextToken(); // race
		tokenizer.nextToken(); // <nr>
		Thread thread = new BlitzThread(socket, game.getText(),
						(int)tokenizer.nval, ifo, this);
		thread.start();
		System.err.println("Thread started...");
	    } else {
		MyDialog dialog = new MyDialog(this, str, "Error");
		// Label label = new Label(str);
		// dialog.add(label);
		// dialog.show();
		System.err.println(str);
	    }
	} catch (Exception e) {
	    System.err.println(e);
	    System.exit(1);
	}
    }

    public static void main(String arg[]) {
	String some_path = (arg.length == 1) ? arg[0] : System.getProperty("user.dir");
	Blitz b = new Blitz(some_path);
    }
}

==> JVPC-0.94.zip: JVPC-0.94/blitz/Blitz.java <==
/**
 * Plug-in for Java VGA-Planets clients, that enables a permanent network
 * connection to the hosting service. The Host will send warnings when the host
 * will be ran. In particular, "host 30" will be sent, which means the host
 * will be ran in 30 seconds. The client should result make a TRN and send it
 * back over the same line.
 *
 * Two Submit buttons (in two windows) confusing?
 */

package jvpc.blitz;

import java.io.*;
import java.net.*;

import java.awt.*;
import java.awt.event.*;
import kero.awt.*;

import jvpc.vga.*;

public class Blitz extends MyFrame {
    FrameAdapter adapter;
    Label dir_name;
    Button change, join;
    InputField host, game, race;
    IntInput port;
    MySocket socket;
    String some_path;
    InputFileOpener ifo;

    public class BlitzAdapter extends FrameAdapter {
	public void quit() {
	    try {
		System.err.println("Quitting...");
		if (socket != null) {  // if never joined, no socket
		    socket.close();
		}
	    } catch (IOException ioe) {
		// What now? Is it closed?
	    }
	    System.exit(0);
	}
    }

    public Blitz(String some_path) {
	super("Blitz Info");
	this.some_path = some_path;
	// this.ifo = ifo;
	setLayout(new GridLayout(0, 1));
	adapter = new BlitzAdapter();
	addWindowListener(adapter);

	Panel dir_p = new Panel(new GridLayout(1, 0));
	dir_p.add(new Label("Directory:"));
	dir_name = new Label(some_path);
	dir_p.add(dir_name);
	change = new Button("Change...");
	addButtonTo(dir_p, change, KeyEvent.VK_C, "change_dir");
	add(dir_p);

	Panel p = new Panel(new GridLayout(1, 0));
        host = new InputField("Ip", "chmeee.org");
	addInputFieldTo(p, host, KeyEvent.VK_I, "empty");
        port = new IntInput("Port", 9000, 1, 0);
	addNumberInputTo(p, port, KeyEvent.VK_P, "empty");
	add(p);
	game = new InputField("Game", "blitz");
	addInputField(game, KeyEvent.VK_G, "empty");
	race = new InputField("Race", "3");
	addInputField(race, KeyEvent.VK_R, "empty");
	join = new Button("Join");
	addButton(join, KeyEvent.VK_J, "join");
	pack();
	show();
    }

    public void change_dir() {
	FileDialog dialog = new FileDialog(this, "GameDir", FileDialog.SAVE);
	dialog.setFile("fizz.bin");
	dialog.setDirectory(some_path);
	dialog.show();
	some_path = dialog.getDirectory();
	// System.err.println("Got dir "+dialog.getDirectory());
	// System.err.println("Got file "+dialog.getFile());
	dir_name.setText(some_path);
	// System.err.println("Got dir "+dialog.getDirectory());
	// System.err.println("Got file "+dialog.getFile());
	pack();
	// show();
    }
    
    public void empty() {}

    public void join() {
	try {
	    socket = new MySocket(host.getText(), port.getInt());
	    socket.write("join "+game.getText()+" "+race.getText()+"\n");
	    String str = socket.gets();
	    System.err.println(str);
	    StreamTokenizer tokenizer = new StreamTokenizer(new StringReader(str));
	    tokenizer.nextToken();
	    String result = tokenizer.sval;
	    if (result.equals("OK")) {
		ifo = new InputFileOpener(some_path, ""+some_path);
		show(false);
		tokenizer.nextToken(); // Game
		tokenizer.nextToken(); // <name>
		tokenizer.nextToken(); // joined
		tokenizer.nextToken(); // as
		tokenizer.nextToken(); // race
		tokenizer.nextToken(); // <nr>
		Thread thread = new BlitzThread(socket, game.getText(),
						(int)tokenizer.nval, ifo, this);
		thread.start();
		System.err.println("Thread started...");
	    } else {
		MyDialog dialog = new MyDialog(this, str, "Error");
		// Label label = new Label(str);
		// dialog.add(label);
		// dialog.show();
		System.err.println(str);
	    }
	} catch (Exception e) {
	    System.err.println(e);
	    System.exit(1);
	}
    }

    public static void main(String arg[]) {
	String some_path = (arg.length == 1) ? arg[0] : System.getProperty("user.dir");
	Blitz b = new Blitz(some_path);
    }
}
